@@ -1,17 +1,14 @@
-# Standard Library
 import functools
 from typing import Callable, Generator
 
-# Django
 from django.http import HttpRequest, HttpResponse
 
-# Local
 from .response import TurboStreamResponse, TurboStreamStreamingResponse
 
 
 def turbo_stream_response(view: Callable) -> Callable:
     @functools.wraps(view)
-    def wrapper(request: HttpRequest, *args, **kwargs):
+    def wrapper(request: HttpRequest, *args, **kwargs) -> HttpResponse:
         response = view(request, *args, **kwargs)
         if isinstance(response, HttpResponse):
             return response
